==> ievv_opensource-0.2.6.tar.gz: ievv_opensource-0.2.6/ievv_opensource/utils/ievvbuildstatic/mediacopy.py <==
import os
import sh
import shutil
from ievv_opensource.utils.ievvbuildstatic import pluginbase
from ievv_opensource.utils.ievvbuildstatic.installers.npm import NpmInstaller


class Plugin(pluginbase.Plugin):
    name = 'mediacopy'

    def __init__(self, sourcefolder='media'):
        """
        Parameters:
            sourcefolder: The folder where media files is located relative to
                the source folder of the :class:`~ievv_opensource.utils.ievvbuild.config.App`.

        """
        self.sourcefolder = sourcefolder

    def get_sourcefolder_path(self):
        return self.app.get_source_path(self.sourcefolder)

    def get_destinationfolder_path(self):
        return self.app.get_destination_path(self.sourcefolder)

    def run(self):
        sourcefolder = self.get_sourcefolder_path()
        self.get_logger().command_start('Copying media')
        if not os.path.exists(sourcefolder):
            self.get_logger().warning('Media source folder, {}, does not exist.'.format(
                sourcefolder))
            return

        destinationfolder = self.get_destinationfolder_path()
        if os.path.exists(destinationfolder):
            self.get_logger().debug('Removing {}'.format(destinationfolder))
            shutil.rmtree(destinationfolder)

        self.get_logger().debug('Copying {} -> {}'.format(sourcefolder, destinationfolder))
        shutil.copytree(sourcefolder, destinationfolder)
        self.get_logger().command_success('Copied media successfully!')

    def get_watch_folders(self):
        """
        We only watch the folder where the less sources are located,
        so this returns the absolute path of the ``sourcefolder``.
        """
        return [self.app.get_source_path(self.sourcefolder)]

==> ievv_opensource-0.2.7.tar.gz: ievv_opensource-0.2.7/ievv_opensource/utils/ievvbuildstatic/mediacopy.py <==
import os
import sh
import shutil
from ievv_opensource.utils.ievvbuildstatic import pluginbase
from ievv_opensource.utils.ievvbuildstatic.installers.npm import NpmInstaller


class Plugin(pluginbase.Plugin):
    name = 'mediacopy'

    def __init__(self, sourcefolder='media'):
        """
        Parameters:
            sourcefolder: The folder where media files is located relative to
                the source folder of the :class:`~ievv_opensource.utils.ievvbuild.config.App`.

        """
        self.sourcefolder = sourcefolder

    def get_sourcefolder_path(self):
        return self.app.get_source_path(self.sourcefolder)

    def get_destinationfolder_path(self):
        return self.app.get_destination_path(self.sourcefolder)

    def run(self):
        sourcefolder = self.get_sourcefolder_path()
        self.get_logger().command_start('Copying media')
        if not os.path.exists(sourcefolder):
            self.get_logger().warning('Media source folder, {}, does not exist.'.format(
                sourcefolder))
            return

        destinationfolder = self.get_destinationfolder_path()
        if os.path.exists(destinationfolder):
            self.get_logger().debug('Removing {}'.format(destinationfolder))
            shutil.rmtree(destinationfolder)

        self.get_logger().debug('Copying {} -> {}'.format(sourcefolder, destinationfolder))
        shutil.copytree(sourcefolder, destinationfolder)
        self.get_logger().command_success('Copied media successfully :)')

    def get_watch_folders(self):
        """
        We only watch the folder where the less sources are located,
        so this returns the absolute path of the ``sourcefolder``.
        """
        return [self.app.get_source_path(self.sourcefolder)]
